PyXMake Developer Guide: PyXMake.Tools.Utility.ChangedWorkingDirectory Class Reference

| PyXMake Developer Guide 1.0 PyXMake

Public Member Functions | Public Attributes | List of all members
PyXMake.Tools.Utility.ChangedWorkingDirectory Class Reference

Class to create 2to3 compatible pickling dictionary. More...

Inheritance diagram for PyXMake.Tools.Utility.ChangedWorkingDirectory:

## Public Member Functions
def | __init__ (self, newPath)
def | __enter__ (self)
def | __exit__ (self, etype, value, traceback)

## Public Attributes
| newPath
| savedPath

## Detailed Description

Class to create 2to3 compatible pickling dictionary.

    Context manager for temporarily changing the current working directory.

    @author: Brian M. Hunt

Inherited from built-in object.

Definition at line 77 of file Utility.py.

The documentation for this class was generated from the following file:

- D:/03_Workspaces/01_Eclipse/pyx_core/PyXMake/Tools/Utility.py